==> radio-button-4.2.34.tgz: package/README.md <==
[![npm](https://img.shields.io/npm/v/@highlight-ui/radio-button)](https://www.npmjs.com/package/@highlight-ui/radio-button)
[![personio.design](https://img.shields.io/static/v1?label=Personio&message=zeroheight&color=yellow)](https://www.personio.design/40d648a47/p/043999-radio-button/b/26fe12)
[![storybook.personio.design](https://img.shields.io/static/v1?label=Personio&message=storybook&color=red)](https://storybook.personio.design/?path=/story/forms-and-input-radiobutton-radiobutton--basic-radio-button)

# @highlight-ui/radio-button

A control that allows the user to toggle between checked and unchecked states. Used to pick one option from a set of multiple available options. If you require a multi-selection input, please use the [Checkbox](https://www.npmjs.com/package/@highlight-ui/checkbox).

## Features

- RadioButton
  - Controlled component
  - Optional label to display next to the RadioButton input
  - Optional sub-label to display under the main label
- RadioButtonGroup
  - Renders multiple RadioButtons given array of options
  - Controlled component
  - Vertical or horizontal display
  - Optional name to apply to all RadioButtons within the group

## Installation

Using npm:

```
$ npm install @highlight-ui/radio-button
```

Using yarn

```
 $ yarn add @highlight-ui/radio-button
```

Using pnpm:

```
$ pnpm install @highlight-ui/radio-button
```

In your (S)CSS file:

```scss
@import url('@highlight-ui/radio-button');
```

Once the package is installed, you can import the library:

```
import { RadioButton, RadioButtonGroup } from '@highlight-ui/radio-button';
```

## Getting started

### RadioButton

```tsx
import React, { useState } from 'react';
import { RadioButton } from '@highlight-ui/radio-button';

export default function RadioButtonExample() {
  const [checkedStatus, setCheckedStatus] = useState(false);

  return (
    <RadioButton
      id="radio-button"
      label="Click me to toggle me"
      subLabel="I am only a radio button input"
      checked={checkedStatus}
      onClick={() => setCheckedStatus(!checkedStatus)}
    />
  );
}
```

### RadioButtonGroup

```tsx
import React from 'react';
import { RadioButtonGroup } from '@highlight-ui/RadioButton';

export default function RadioButtonGroupExample() {
  const [checked, setChecked] = useState<string | number | undefined>(
    undefined,
  );
  const options = [
    { value: 'option-a', label: 'Option A', subLabel: 'Most important' },
    { value: 'option-b', label: 'Option B', subLabel: 'Average' },
    { value: 'option-c', label: 'Option C', subLabel: 'Lowest priority' },
  ];

  return (
    <RadioButtonGroup
      name="RadioButton-group"
      orientation="horizontal"
      options={options}
      value={checked}
      onChange={(option) => setChecked(option.value)}
    />
  );
}
```

## Props 📜

### RadioButton

| Prop        | Type                               | Required | Default | Description                                                                                                                                                                                              |
| :---------- | :--------------------------------- | :------- | :------ | :------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `checked`   | `boolean`                          | Yes      |         | Checked status of the radio button                                                                                                                                                                       |
| `onClick`   | `function(e: MouseEvent): void`    | Yes      |         | Function called when radio button input is clicked on                                                                                                                                                    |
| `onKeyUp`   | `function(e: KeyboardEvent): void` | No       | `null`  | Function called when radio button input interaction involves a key release                                                                                                                               |
| `metadata`  | `ComponentMetadata`                | No       | `null`  | Appended as data attributes - contains `testId` and `actionName` ([Source](https://gitlab.personio-internal.de/personio/platform/highlight-ui/-/blob/master/packages/utils/commons/src/types.ts#L19-22)) |
| `className` | `string`                           | No       | `null`  | Class name to apply to the the radio button input                                                                                                                                                        |
| `label`     | `string`                           | No       | `null`  | Text displayed next to the radio button input                                                                                                                                                            |
| `subLabel`  | `string`                           | No       | `null`  | Text displayed below the main label                                                                                                                                                                      |
| `id`        | `string`                           | No       | `null`  | ID to apply to the radio button input                                                                                                                                                                    |
| `disabled`  | `boolean`                          | No       | `false` | Whether the radio button is disabled                                                                                                                                                                     |

### RadioButtonGroup

Note that the `RadioButtonGroupOption` type matches the `RadioButton` listed properties above.

| Prop          | Type                                             | Required | Default    | Description                                                                                                                                                                                              |
| :------------ | :----------------------------------------------- | :------- | :--------- | :------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `value`       | `RadioButtonGroupOption['value']`                | Yes      |            | Currently checked value                                                                                                                                                                                  |
| `onChange`    | `function(option: RadioButtonGroupOption): void` | Yes      |            | Function called when the checked status of an option changes                                                                                                                                             |
| `metadata`    | `ComponentMetadata`                              | No       | `null`     | Appended as data attributes - contains `testId` and `actionName` ([Source](https://gitlab.personio-internal.de/personio/platform/highlight-ui/-/blob/master/packages/utils/commons/src/types.ts#L19-22)) |
| `className`   | `string`                                         | No       | `null`     | Class name to apply to the the radio button input                                                                                                                                                        |
| `name`        | `string`                                         | No       | `null`     | Name applied to all radio buttons in the group                                                                                                                                                           |
| `disabled`    | `boolean`                                        | No       | `false`    | Whether all radio buttons in the group are disabled                                                                                                                                                      |
| `orientation` | `vertical` or `horizontal`                       | No       | `vertical` | Display of the radio button group                                                                                                                                                                        |
| `options`     | `RadioButtonGroupOption[]`                       | Yes      |            | Options to render as a group                                                                                                                                                                             |

## Accessibility ♿️

Following [base accesibility guidelines](https://www.magentaa11y.com/checklist-web/radio/), the radio-button input currently:

- Allows clicking radio button input and main label to check or uncheck
- Associates the radio button input with its label through the `for` prop referring to the `id`

Potential future improvements to make it more accessible:

- Adding focus on the whole radio button and label container
- Including `aria` tags to indicate checked and disabled states

## Testing

There are a number of unit tests covering the `RadioButton` and `RadioButtonGroup` components, the snippets below can serve as a base to expand future testing if new behaviours are added.

The relevant render methods provide the option to add or override prop values.

### RadioButton

```tsx
import React from 'react';
import { render } from '@testing-library/react';
import { RadioButton, RadioButtonProps } from '@highlight-ui/radio-button';

type Optional<T, K extends keyof T> = Omit<T, K> & Partial<T>;
type RadioButtonWrapperProps = Optional<
  RadioButtonProps,
  'checked' | 'onClick'
>;

function RadioButtonWrapper(props: RadioButtonWrapperProps) {
  const [checked, setChecked] = useState(false);

  return (
    <RadioButton
      checked={checked}
      onClick={() => setChecked(!checked)}
      {...props}
    />
  );
}

describe('RadioButtonTest', () => {
  const renderRadioButtonWrapper = (props: RadioButtonWrapperProps) => {
    return render(<RadioButtonWrapper {...props} />);
  };

  it('test description', () => {
    renderRadioButtonWrapper({});
    // write your expect here
  });
});
```

### RadioButtonGroup

```tsx
import React from 'react';
import { render } from '@testing-library/react';

import { RadioButtonGroup, RadioButtonGroupProps, RadioButtonGroupOption }  from '@highlight-ui/radio-button';

type Optional<T, K extends keyof T> = Omit<T, K> & Partial<T>;
type RadioButtonGroupWrapperProps = Optional<
  RadioButtonGroupProps,
  'value' | 'onChange' | 'options'
>;

function RadioButtonGroupWrapper(props: RadioButtonGroupWrapperProps) {
  const [checked, setChecked] = useState<string | number | undefined>(
    undefined,
  );
  const options = [
    { value: 'option-a', label: 'Option A', subLabel: 'Most important' },
    { value: 'option-b', label: 'Option B', subLabel: 'Average' },
    { value: 'option-c', label: 'Option C', subLabel: 'Lowest priority' },
  ];

  return (
    <RadioButtonGroup
      name="RadioButton-group"
      options={options}
      value={checked}
      onChange={(option) => setChecked(option.value)}
      {...props}
    />
  );
}

describe('RadioButtonGroupTest', () => {
  const renderRadioButtonGroupWrapper = (props: RadioButtonGroupWrapperProps) => {
    return render(<RadioButtonWrapper {...props} />);
  };

  it('test description', () => {
    renderRadioButtonGroupWrapper({});
    // write your expect here
  });
};
```

## Place in design system 💻

The radio button and radio button group are components currently unused in other components and packages.

## Contributing 🖌️

Please visit [personio.design](https://www.personio.design/40d648a47/v/0/p/043999-radio-button/b/26fe12) for usage guidelines and visual examples.

If you're interested in contributing, please visit our [contribution page](https://www.personio.design/40d648a47/v/0/p/22ac59-support--contribute/b/463fdd).

==> radio-button-4.3.0.tgz: package/README.md <==
[![npm](https://img.shields.io/npm/v/@highlight-ui/radio-button)](https://www.npmjs.com/package/@highlight-ui/radio-button)
[![personio.design](https://img.shields.io/static/v1?label=Personio&message=zeroheight&color=yellow)](https://www.personio.design/40d648a47/p/043999-radio-button/b/26fe12)
[![storybook.personio.design](https://img.shields.io/static/v1?label=Personio&message=storybook&color=red)](https://storybook.personio.design/?path=/story/forms-and-input-radiobutton-radiobutton--basic-radio-button)

# @highlight-ui/radio-button

A control that allows the user to toggle between checked and unchecked states. Used to pick one option from a set of multiple available options. If you require a multi-selection input, please use the [Checkbox](https://www.npmjs.com/package/@highlight-ui/checkbox).

## Features

- RadioButton
  - Controlled component
  - Optional label to display next to the RadioButton input
  - Optional sub-label to display under the main label
- RadioButtonGroup
  - Renders multiple RadioButtons given array of options
  - Controlled component
  - Vertical or horizontal display
  - Optional name to apply to all RadioButtons within the group

## Installation

Using npm:

```bash
npm install @highlight-ui/radio-button
```

Using yarn:

```bash
yarn add @highlight-ui/radio-button
```

Using pnpm:

```bash
pnpm install @highlight-ui/radio-button
```

In your (S)CSS file:

```scss
@import url('@highlight-ui/radio-button');
```

Once the package is installed, you can import the library:

```
import { RadioButton, RadioButtonGroup } from '@highlight-ui/radio-button';
```

## Getting started

### RadioButton

```tsx
import React, { useState } from 'react';
import { RadioButton } from '@highlight-ui/radio-button';

export default function RadioButtonExample() {
  const [checkedStatus, setCheckedStatus] = useState(false);

  return (
    <RadioButton
      id="radio-button"
      label="Click me to toggle me"
      subLabel="I am only a radio button input"
      checked={checkedStatus}
      onClick={() => setCheckedStatus(!checkedStatus)}
    />
  );
}
```

### RadioButtonGroup

```tsx
import React from 'react';
import { RadioButtonGroup } from '@highlight-ui/RadioButton';

export default function RadioButtonGroupExample() {
  const [checked, setChecked] = useState<string | number | undefined>(
    undefined,
  );
  const options = [
    { value: 'option-a', label: 'Option A', subLabel: 'Most important' },
    { value: 'option-b', label: 'Option B', subLabel: 'Average' },
    { value: 'option-c', label: 'Option C', subLabel: 'Lowest priority' },
  ];

  return (
    <RadioButtonGroup
      name="RadioButton-group"
      orientation="horizontal"
      options={options}
      value={checked}
      onChange={(option) => setChecked(option.value)}
    />
  );
}
```

## Props 📜

### RadioButton

| Prop        | Type                               | Required | Default | Description                                                                                                                                                                                              |
| :---------- | :--------------------------------- | :------- | :------ | :------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `checked`   | `boolean`                          | Yes      |         | Checked status of the radio button                                                                                                                                                                       |
| `onClick`   | `function(e: MouseEvent): void`    | Yes      |         | Function called when radio button input is clicked on                                                                                                                                                    |
| `onKeyUp`   | `function(e: KeyboardEvent): void` | No       | `null`  | Function called when radio button input interaction involves a key release                                                                                                                               |
| `metadata`  | `ComponentMetadata`                | No       | `null`  | Appended as data attributes - contains `testId` and `actionName` ([Source](https://gitlab.personio-internal.de/personio/platform/highlight-ui/-/blob/master/packages/utils/commons/src/types.ts#L19-22)) |
| `className` | `string`                           | No       | `null`  | Class name to apply to the the radio button input                                                                                                                                                        |
| `label`     | `string`                           | No       | `null`  | Text displayed next to the radio button input                                                                                                                                                            |
| `subLabel`  | `string`                           | No       | `null`  | Text displayed below the main label                                                                                                                                                                      |
| `id`        | `string`                           | No       | `null`  | ID to apply to the radio button input                                                                                                                                                                    |
| `disabled`  | `boolean`                          | No       | `false` | Whether the radio button is disabled                                                                                                                                                                     |

### RadioButtonGroup

Note that the `RadioButtonGroupOption` type matches the `RadioButton` listed properties above.

| Prop          | Type                                             | Required | Default    | Description                                                                                                                                                                                              |
| :------------ | :----------------------------------------------- | :------- | :--------- | :------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `value`       | `RadioButtonGroupOption['value']`                | Yes      |            | Currently checked value                                                                                                                                                                                  |
| `onChange`    | `function(option: RadioButtonGroupOption): void` | Yes      |            | Function called when the checked status of an option changes                                                                                                                                             |
| `metadata`    | `ComponentMetadata`                              | No       | `null`     | Appended as data attributes - contains `testId` and `actionName` ([Source](https://gitlab.personio-internal.de/personio/platform/highlight-ui/-/blob/master/packages/utils/commons/src/types.ts#L19-22)) |
| `className`   | `string`                                         | No       | `null`     | Class name to apply to the the radio button input                                                                                                                                                        |
| `name`        | `string`                                         | No       | `null`     | Name applied to all radio buttons in the group                                                                                                                                                           |
| `disabled`    | `boolean`                                        | No       | `false`    | Whether all radio buttons in the group are disabled                                                                                                                                                      |
| `orientation` | `vertical` or `horizontal`                       | No       | `vertical` | Display of the radio button group                                                                                                                                                                        |
| `options`     | `RadioButtonGroupOption[]`                       | Yes      |            | Options to render as a group                                                                                                                                                                             |

## Accessibility ♿️

Following [base accesibility guidelines](https://www.magentaa11y.com/checklist-web/radio/), the radio-button input currently:

- Allows clicking radio button input and main label to check or uncheck
- Associates the radio button input with its label through the `for` prop referring to the `id`

Potential future improvements to make it more accessible:

- Adding focus on the whole radio button and label container
- Including `aria` tags to indicate checked and disabled states

## Testing

There are a number of unit tests covering the `RadioButton` and `RadioButtonGroup` components, the snippets below can serve as a base to expand future testing if new behaviours are added.

The relevant render methods provide the option to add or override prop values.

### RadioButton

```tsx
import React from 'react';
import { render } from '@testing-library/react';
import { RadioButton, RadioButtonProps } from '@highlight-ui/radio-button';

type Optional<T, K extends keyof T> = Omit<T, K> & Partial<T>;
type RadioButtonWrapperProps = Optional<
  RadioButtonProps,
  'checked' | 'onClick'
>;

function RadioButtonWrapper(props: RadioButtonWrapperProps) {
  const [checked, setChecked] = useState(false);

  return (
    <RadioButton
      checked={checked}
      onClick={() => setChecked(!checked)}
      {...props}
    />
  );
}

describe('RadioButtonTest', () => {
  const renderRadioButtonWrapper = (props: RadioButtonWrapperProps) => {
    return render(<RadioButtonWrapper {...props} />);
  };

  it('test description', () => {
    renderRadioButtonWrapper({});
    // write your expect here
  });
});
```

### RadioButtonGroup

```tsx
import React from 'react';
import { render } from '@testing-library/react';

import { RadioButtonGroup, RadioButtonGroupProps, RadioButtonGroupOption }  from '@highlight-ui/radio-button';

type Optional<T, K extends keyof T> = Omit<T, K> & Partial<T>;
type RadioButtonGroupWrapperProps = Optional<
  RadioButtonGroupProps,
  'value' | 'onChange' | 'options'
>;

function RadioButtonGroupWrapper(props: RadioButtonGroupWrapperProps) {
  const [checked, setChecked] = useState<string | number | undefined>(
    undefined,
  );
  const options = [
    { value: 'option-a', label: 'Option A', subLabel: 'Most important' },
    { value: 'option-b', label: 'Option B', subLabel: 'Average' },
    { value: 'option-c', label: 'Option C', subLabel: 'Lowest priority' },
  ];

  return (
    <RadioButtonGroup
      name="RadioButton-group"
      options={options}
      value={checked}
      onChange={(option) => setChecked(option.value)}
      {...props}
    />
  );
}

describe('RadioButtonGroupTest', () => {
  const renderRadioButtonGroupWrapper = (props: RadioButtonGroupWrapperProps) => {
    return render(<RadioButtonWrapper {...props} />);
  };

  it('test description', () => {
    renderRadioButtonGroupWrapper({});
    // write your expect here
  });
};
```

## Place in design system 💻

The radio button and radio button group are components currently unused in other components and packages.

## Contributing 🖌️

Please visit [personio.design](https://www.personio.design/40d648a47/v/0/p/043999-radio-button/b/26fe12) for usage guidelines and visual examples.

If you're interested in contributing, please visit our [contribution page](https://www.personio.design/40d648a47/v/0/p/22ac59-support--contribute/b/463fdd).
